<?php

	namespace App\Controller;

	use App\Controller\AppController;
	use Cake\Cache\Cache;

	class DeparturesController extends AppController {

		const MAX_DEPARTURES	= 100;

		public function initialize() {
			parent::initialize();
			$this->loadComponent('Configuration');
			$this->loadComponent('Departures');
			$this->loadComponent('Csrf');
		}

		public function index() {

			// set variable for view
			$this->set('departure_result', $this->getDepartures());
			// render
			$this->render();

		}

		private function getDepartures() {
			// load session
			$session = $this->request->session();
			// define options variable
			$options = array();
			// define result variable
			$result = array();
			// load options
			if ($this->request->query('config') == null)
			{
				$config_name = 'default';
			}	else {
				$config_name = $this->request->query('config');
			}
			$options = $this->Configuration->getConfiguration('departure', $config_name,'panel/departure');
			// are there any stations defined?
			$result['error'] = null;
			if (count($options['stops']) == 0) {
				$result['error'] = 'no stops defined';
				$result['config']['name'] = $config_name;
				$result['config']['type'] = 'panel/departure';
				$result['options'] = $options;
				return $result;
			}

			// restrict maximum departures to MAX_DEPARTURES
			$options['max'] = $options['max'] < $this::MAX_DEPARTURES ? $options['max'] : $this::MAX_DEPARTURES;
			// sort stops by name (so they look the same no matter the order in config)
			usort($options['stops'], function($a, $b) {
				return strcmp($a, $b);
			});

			// read from cache?
			$cache_name = "vrr_".md5(json_encode($options));
			if (($result = Cache::read($cache_name, 'departures')) === false) {
				// grab data
				$result = $this->Departures->grabData($options);
				// write to cache
				Cache::write($cache_name, $result, 'departures');
			}
			// testing
			return $result;
		}
	}
